PowerSaveMode

Enum PowerSaveMode 

#[non_exhaustive]
pub enum PowerSaveMode { None, Minimum, Maximum, }
Available on crate feature unstable only.
Power saving mode settings for the modem.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

No power saving.



Minimum

Minimum power save mode. In this mode, station wakes up to receive beacon every DTIM period.



Maximum

Maximum power save mode. In this mode, interval to receive beacons is determined by the listen_interval config option.