ControllerConfig

Struct ControllerConfig 

#[non_exhaustive]
pub struct ControllerConfig { /* private fields */ }
Available on crate feature wifi only.
Wi-Fi configuration.

Implementations

Source

impl ControllerConfig

pub fn with_country_info(self, country_info: impl Into<CountryInfo>) -> Self

Available on crate feature unstable only.

Assign the given value to the country_info field.

pub fn country_info(&self) -> CountryInfo

Available on crate feature unstable only.

Country info.

pub fn with_rx_queue_size(self, rx_queue_size: usize) -> Self

Available on crate feature unstable only.

Assign the given value to the rx_queue_size field.

pub fn rx_queue_size(&self) -> usize

Available on crate feature unstable only.

Size of the RX queue in frames.

pub fn with_tx_queue_size(self, tx_queue_size: usize) -> Self

Available on crate feature unstable only.

Assign the given value to the tx_queue_size field.

pub fn tx_queue_size(&self) -> usize

Available on crate feature unstable only.

Size of the TX queue in frames.

pub fn with_static_rx_buf_num(self, static_rx_buf_num: u8) -> Self

Available on crate feature unstable only.

Assign the given value to the static_rx_buf_num field.

pub fn static_rx_buf_num(&self) -> u8

Available on crate feature unstable only.

Max number of Wi-Fi static RX buffers.

Each buffer takes approximately 1.6KB of RAM. The static rx buffers are allocated when esp_wifi_init is called, they are not freed until esp_wifi_deinit is called.

Wi-Fi hardware use these buffers to receive all 802.11 frames. A higher number may allow higher throughput but increases memory use. If Self::ampdu_rx_enable is enabled, this value is recommended to set equal or bigger than Self::rx_ba_win in order to achieve better throughput and compatibility with both stations and APs.

pub fn with_dynamic_rx_buf_num(self, dynamic_rx_buf_num: u16) -> Self

Available on crate feature unstable only.

Assign the given value to the dynamic_rx_buf_num field.

pub fn dynamic_rx_buf_num(&self) -> u16

Available on crate feature unstable only.

Max number of Wi-Fi dynamic RX buffers

Set the number of Wi-Fi dynamic RX buffers, 0 means unlimited RX buffers will be allocated (provided sufficient free RAM). The size of each dynamic RX buffer depends on the size of the received data frame.

For each received data frame, the Wi-Fi driver makes a copy to an RX buffer and then delivers it to the high layer TCP/IP stack. The dynamic RX buffer is freed after the higher layer has successfully received the data frame.

For some applications, Wi-Fi data frames may be received faster than the application can process them. In these cases we may run out of memory if RX buffer number is unlimited (0).

If a dynamic RX buffer limit is set, it should be at least the number of static RX buffers.

pub fn with_static_tx_buf_num(self, static_tx_buf_num: u8) -> Self

Available on crate feature unstable only.

Assign the given value to the static_tx_buf_num field.

pub fn static_tx_buf_num(&self) -> u8

Available on crate feature unstable only.

Set the number of Wi-Fi static TX buffers.

Each buffer takes approximately 1.6KB of RAM. The static RX buffers are allocated when esp_wifi_init() is called, they are not released until esp_wifi_deinit() is called.

For each transmitted data frame from the higher layer TCP/IP stack, the Wi-Fi driver makes a copy of it in a TX buffer.

For some applications especially UDP applications, the upper layer can deliver frames faster than Wi-Fi layer can transmit. In these cases, we may run out of TX buffers.

pub fn with_dynamic_tx_buf_num(self, dynamic_tx_buf_num: u16) -> Self

Available on crate feature unstable only.

Assign the given value to the dynamic_tx_buf_num field.

pub fn dynamic_tx_buf_num(&self) -> u16

Available on crate feature unstable only.

Set the number of Wi-Fi dynamic TX buffers.

The size of each dynamic TX buffer is not fixed, it depends on the size of each transmitted data frame.

For each transmitted frame from the higher layer TCP/IP stack, the Wi-Fi driver makes a copy of it in a TX buffer.

For some applications, especially UDP applications, the upper layer can deliver frames faster than Wi-Fi layer can transmit. In these cases, we may run out of TX buffers.

pub fn with_ampdu_rx_enable(self, ampdu_rx_enable: bool) -> Self

Available on crate feature unstable only.

Assign the given value to the ampdu_rx_enable field.

pub fn ampdu_rx_enable(&self) -> bool

Available on crate feature unstable only.

Select this option to enable AMPDU RX feature.

pub fn with_ampdu_tx_enable(self, ampdu_tx_enable: bool) -> Self

Available on crate feature unstable only.

Assign the given value to the ampdu_tx_enable field.

pub fn ampdu_tx_enable(&self) -> bool

Available on crate feature unstable only.

Select this option to enable AMPDU TX feature.

pub fn with_amsdu_tx_enable(self, amsdu_tx_enable: bool) -> Self

Available on crate feature unstable only.

Assign the given value to the amsdu_tx_enable field.

pub fn amsdu_tx_enable(&self) -> bool

Available on crate feature unstable only.

Select this option to enable AMSDU TX feature.

pub fn with_rx_ba_win(self, rx_ba_win: u8) -> Self

Available on crate feature unstable only.

Assign the given value to the rx_ba_win field.

pub fn rx_ba_win(&self) -> u8

Available on crate feature unstable only.

Set the size of Wi-Fi Block Ack RX window.

Generally a bigger value means higher throughput and better compatibility but more memory. Most of time we should NOT change the default value unless special reason, e.g. test the maximum UDP RX throughput with iperf etc. For iperf test in shieldbox, the recommended value is 9~12.

If PSRAM is used and Wi-Fi memory is preferred to allocate in PSRAM first, the default and minimum value should be 16 to achieve better throughput and compatibility with both stations and APs.

pub fn with_initial_config(self, initial_config: Config) -> Self

Assign the given value to the initial_config field.

pub fn initial_config(&self) -> &Config

Initial Wi-Fi configuration.