pub struct CountryInfo { /* private fields */ }Available on crate feature
unstable only.Expand description
Country information.
Defaults to China (CN) with Operating Class “0”.
To create a CountryInfo instance, use the from method first, then set additional
properties using the builder methods.
Example
use esp_radio::wifi::{CountryInfo, OperatingClass};
let country_info = CountryInfo::from(*b"CN").with_operating_class(OperatingClass::Indoors);For more information, see the Wi-Fi Country Code in the ESP-IDF documentation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl CountryInfo
impl CountryInfo
Sourcepub fn with_operating_class(self, operating_class: OperatingClass) -> Self
pub fn with_operating_class(self, operating_class: OperatingClass) -> Self
Assign the given value to the operating_class field.
Sourcepub fn operating_class(&self) -> OperatingClass
pub fn operating_class(&self) -> OperatingClass
Operating class.