pub struct RxControlInfo {Show 19 fields
pub rssi: i32,
pub rate: u32,
pub sig_mode: u32,
pub mcs: u32,
pub cwb: u32,
pub smoothing: u32,
pub not_sounding: u32,
pub aggregation: u32,
pub stbc: u32,
pub fec_coding: u32,
pub sgi: u32,
pub ampdu_cnt: u32,
pub channel: u32,
pub secondary_channel: SecondaryChannel,
pub timestamp: Instant,
pub noise_floor: i32,
pub ant: u32,
pub sig_len: u32,
pub rx_state: u32,
}unstable only.Expand description
The radio metadata header of the received packet, which is the common header at the beginning of all RX callback buffers in promiscuous mode.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
rssi: i32Received Signal Strength Indicator (RSSI) of the packet, in dBm.
rate: u32PHY rate encoding of the packet. Only valid for non-HT (802.11b/g) packets.
sig_mode: u32Protocol of the received packet: 0 for non-HT (11bg), 1 for HT (11n), 3 for VHT (11ac).
mcs: u32Modulation and Coding Scheme (MCS). Indicates modulation for HT (11n) packets.
cwb: u32Channel bandwidth of the packet: 0 for 20MHz, 1 for 40MHz.
smoothing: u32Channel estimate smoothing: 1 recommends smoothing; 0 recommends per-carrier-independent estimate.
not_sounding: u32Sounding indicator: 0 for sounding PPDU (used for channel estimation); 1 for non-sounding PPDU.
aggregation: u32Aggregation status: 0 for MPDU packet, 1 for AMPDU packet.
stbc: u32Space-Time Block Coding (STBC) status: 0 for non-STBC packet, 1 for STBC packet.
fec_coding: u32Forward Error Correction (FEC) status: indicates if LDPC coding is used for 11n packets.
sgi: u32Short Guard Interval (SGI): 0 for long guard interval, 1 for short guard interval.
ampdu_cnt: u32Number of subframes aggregated in an AMPDU packet.
channel: u32Primary channel on which the packet is received.
secondary_channel: SecondaryChannelSecondary channel on which the packet is received.
timestamp: InstantTimestamp of when the packet is received, in microseconds. Precise only if modem sleep or light sleep is not enabled.
noise_floor: i32Noise floor of the Radio Frequency module, in dBm.
ant: u32Antenna number from which the packet is received: 0 for antenna 0, 1 for antenna 1.
sig_len: u32Length of the packet including the Frame Check Sequence (FCS).
rx_state: u32State of the packet: 0 for no error, other values indicate error codes.