pub enum AccessPointStationEventInfo {
Connected(AccessPointStationConnectedInfo),
Disconnected(AccessPointStationDisconnectedInfo),
}Available on crate feature
wifi only.Expand description
Variants
Connected(AccessPointStationConnectedInfo)
Information about a station connected to the access point.
Disconnected(AccessPointStationDisconnectedInfo)
Information about a station disconnected from the access point.